#
# spec file for package fuzzel
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fuzzel
Version:        1.12.0
Release:        1.1
Summary:        A Wayland-native application launcher, similar to rofi's drun mode
License:        MIT
Group:          System/X11/Utilities
URL:            https://codeberg.org/dnkl/fuzzel
Source:         https://codeberg.org/dnkl/fuzzel/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        https://codeberg.org/dnkl/fuzzel/releases/download/%{version}/%{name}-%{version}.tar.gz.sig
# https://keyserver.ubuntu.com/pks/lookup?op=get&search=0xb19964fbba09664cc81027ed5bbd4992c116573f
Source2:        %{name}.keyring
BuildRequires:  meson >= 0.58
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  scdoc
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(fcft) <  4.0.0
BuildRequires:  pkgconfig(fcft) >= 3.0.0
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(tllist) >= 1.0.1
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(wayland-scanner)
BuildRequires:  pkgconfig(xkbcommon)
%if 0%{?sle_version} >= 150400
BuildRequires:  gcc11
%else
BuildRequires:  gcc >= 8
%endif

%description
A Wayland-native application launcher, similar to rofi's drun mode.

%prep
%autosetup -p1

%package        zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and zsh)
Requires:       %{name}
Requires:       zsh

%description    zsh-completion
Zsh command-line completion support for %{name}

%package        fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and fish)
Requires:       %{name}
Requires:       fish

%description    fish-completion
Fish command-line completion support for %{name}.

%build
export CFLAGS="%{optflags}"
%meson \
-Denable-cairo=enabled -Dpng-backend=libpng -Dsvg-backend=nanosvg \
%if 0%{?sle_version} == 150400 && 0%{?is_opensuse}
# For whatever reason, meson >= 0.58 should already support the c18 standard.
	-Dc_std=c11 \
%endif
    -Db_lto=true

%meson_build

%install
%meson_install

%files
%dir %{_datadir}/doc/%{name}
%license %{_datadir}/doc/%{name}/LICENSE
%doc %{_datadir}/doc/%{name}/README.md
%{_datadir}/doc/%{name}/CHANGELOG.md

%{_bindir}/%{name}

%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man5/%{name}.ini.5%{?ext_man}

%dir %{_sysconfdir}/xdg/%{name}
%config(noreplace) %{_sysconfdir}/xdg/%{name}/%{name}.ini

%files zsh-completion
%dir %{_datadir}/zsh/
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_%{name}

%files fish-completion
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/fuzzel.fish

%changelog
* Fri Jun 27 2025 Alessio Biancalana <dottorblaster@opensuse.org>
- Update to 1.12.0:
  - Added:
  * Add support for fallback icons in dmenu mode using comma-separated
    values in the icon metadata ([#504][504]).
  * `--namespace` command line option ([#512][512]).
  * Gamma-correct blending. Disabled by default. Enable with the new
    `--gamma-correct` command line option, or by setting
    `gamma-correct-blending=yes` in `fuzzel.ini`. Note that
    gamma-correct blending **is not supported in cairo enabled builds of
    fuzzel**, due to the lack of 16-bit image buffers in cairo
    ([#546][546]).
  * `scaling-filter` option (and the corresponding `--scaling-filter`
    command line option). This option defines which scaling filter
    fuzzel uses when down scaling PNGs ([#553][553]).
  * `--minimal-lines` command line and config option, causing fuzzel to
    adjust the number of displayed lines to the minimum of `--lines` and
    the number of input lines ([#144][144])
  * Touchscreen support ([#594][594])
  * `{cmd}` placeholder support in the `terminal` option. When `{cmd}` is
    present in the terminal command string, it will be replaced with the
    application command instead of appending the command at the end. Useful
    for setting the title or app_id. ([#600][600])
  - Changed:
  * Scrolling speed is now line-by-line instead of page-by-page ([#586][586])
  * Number of render workers is now automatically limited to the number
    of displayed entries.
  * wayland-protocols >= 1.41 is now required.
  * pixman >= 0.46.0 is now required.
  * fcft >= 3.3.1 is now required.
  * In application mode (not dmenu), fuzzel now ignores icon theme
    directories whose `Context` field is not `Application` or
    `Apps`. This is for performance reasons ([#553][553])
  * Default down scaling filter changed from `lanczos3` to `box`
    ([#553][553]).
  * Use the width of 'o' instead of 'W' when calculating the window
    width ([#560][560]).
  * Default icon theme from `hicolor` to `default`.
  * Error out (with an appropriate error message) if the command line we
    attempt to execute has non-specification-compliant quoting.
  - Fixed:
  * Crash when `--match-workers >= 100` ([#507][507]).
  * Keyboard modifiers not being reset on keyboard leave events.
  * `--with-nth`: non-selected columns still being matched.
  * Match highlighting being offset when `--with-nth` is used
    ([#551][551]).
  * Too wide PNGs bleeding into the text ([#313][313]).
  * Lookup of icon themes in `~/.icons` and `/usr/share/pixmans`.
  * Missing shell completions for `--launch-prefix`.
  * Missing shell completions for `--prompt-only`.
  * Empty window being displayed despite `--no-run-if-empty` being used.
  * Fix border width and scaling for mixed-DPI environments ([#595][595])
* Tue Sep 24 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Completion packages require main package
* Fri Sep 13 2024 llyyr <llyyr@yukari.in>
- Update to 1.11.1:
  - Added:
  * New option --hide-before-typing for application launcher mode
    hides the list until the first character is typed
  - Changed:
  * Logging no longer reports "aborted" if dmenu mode is called with
    no input
  - Fixed:
  * Crash when the border size is larger than the border radius
  * Regression: cursor not centered when using a custom line height
  * Regression: selected background not rendered on top of the
    regular background
  * Regression: Supporting XDG_CONFIG_HOME as absolute path but not
    relative should be supported
* Mon Sep  9 2024 llyyr <llyyr@yukari.in>
- Update to 1.11.0:
  - Added:
  * Nanosvg updated to 93ce879dc4c04a3ef1758428ec80083c38610b1f
  * New options `--x-margin` `--y-margin` which place the launcher some
    distance away from the anchor point, in pixels. Default to 0
    ([#344][344]).
  * Support for the `StartupNotify` key in `.desktop` files.
  * Log output now respects the [`NO_COLOR`](http://no-color.org/)
    environment variable.
  * Rounded corners without cairo. With this, the **only** time cairo is
    needed is when you want to use the librsvg SVG backend. For nanosvg
    builds, there is no longer any need to link against cairo.
  * Support for linking against a system provided nanosvg library. See
    the new `-Dsystem-nanosvg` meson option. Default's to `disabled`
    (i.e. use the bundled version).
  * Mouse support. Left click selects/launches, right click quits
    fuzzel, wheel scrolls (a page at at time). This is, for the time
    being, not configurable ([#131][131])
  * `--cache=PATH` command line option, and `cache` option to
    `fuzzel.ini`, allowing a custom cache location to be used
    ([#189][189], [#219][219]).
  * `expunge` key binding, to remove an entry from the cache. Mapped to
    shift+delete by default.
  * `--prompt-color` and `colors.prompt`, controlling the
    text/foreground color of the prompt ([#365][365]).
  * `--input-color` and `colors.input`, controlling the text/foreground
    color of the input string ([#365][365]).
  * Much improved performance with large amounts of input ([#305][305]).
  * Improved rendering performance, by using threads. See the new
    `--render-workers` command line option, and the new `render-workers`
    option in `fuzzel.ini`.
  * dmenu mode: `--prompt-only=PROMPT` command line option
    ([#276][276]).
  * dmenu mode: start rendering input before STDIN has been closed.
  * `--match-workers` command line option and the new `match-workers`
    option in `fuzzel.ini`.
  * `delayed-filter-ms`, `delayed-filter-limit` options to `fuzzel.ini`,
    and `--delayed-filter-ms` and `--delayed-filter-limit` command line
    options.
  * Match count can now printed at the right-hand side of the input
    prompt. It is disabled by default, and can be enabled with either
    the `--counter` command line option, or the `match-counter` setting
    in `fuzzel.ini`.
  * `--counter-color` and `colors.counter`, controlling the color of the
    match count. The default value is `93a1a1ff` (_base1_ in the
    solarized palette).
  * The currently selected entry may now be rendered with a bold
    font. It is disabled by default, and can be enabled either via the
    new `--use-bold` command line option, or by setting `use-bold=yes`,
    in `fuzzel.ini`.
  * `sort-result` option to `fuzzel.ini`, and `--no-sort` command line
    option.
  * Placeholder text (for the input box), controlled by the new
    `--placeholder`, `--placeholder-color` command line options, and the
    `placeholder` and `colors.placeholder` options in `fuzzel.ini`
    ([#188][188]).
  * `--search=TEXT` command line option, allowing you to "pre-filter"
    the result ([#][274][274]).
  * Support for pasting text into fuzzel. Both the regular clipboard,
    and the primary clipboard are supported. See the new
    `clipboard-paste` and `primary-paste` key bindings ([#200][200]).
  - Changed:
  * The cache now stores desktop file **IDs** instead of the application
    titles. This way, we do not store multiple cache entries with the
    same value (title) ([#339][339]).
  * Always fallback on the icon theme `hicolor`.
  * Quitting without executing an entry in dmenu mode now exits with
    code 2 instead of 1 ([#353][353]).
  * The default `layer` is now `overlay` instead of `top`. This means
    fuzzel now renders on top of fullscreen windows by default
    ([#81][81]).
  * `--no-fuzzy` option has been replaced with `--match-mode`.
    Default match mode is `fzf`. Other options are `fuzzy` and `exact`. See
    `man fuzzel.ini` for details.
    ([#305][305]).
  * Default text color of the prompt and the selected entry to
    `586e75ff` (_base01_ in the solarized palette).
  * Initial application sorting is now done case insensitive.
  * Background is no longer transparent by default. You can change this
    by setting `colors.background`.
  * Search string is now font shaped, improving support for e.g Arabic
    ([#398][398]).
  - Fixed:
  * PNG images being way too dark.
  * Crash when the cache contains strings that are not valid in the
    current locale ([#337][337]).
  * Crash when `tabs` (in `fuzzel.ini`) is set to `0` ([#348][348]).
  * Crash while loading the cache, when `--list-executables-in-path` is
    used ([#356][356])
  * Rounding of window size when fractional scaling is used.
  * Dmenu mode failing with _"failed to read from stdin: Resource
    temporarily unavailable"_.
  * First frame flickers when fractional scaling is used.
  * Borders, padding etc not updated on scale changes when
    `dpi-aware=yes`. This mostly affected setups using fractional
    scaling, but all setups were affected in one way or another.
  * Mouse selection not working correctly (wrong item selected) when
    `dpi-aware=yes` and desktop scaling was enabled.
* Mon Apr 22 2024 Joshua Smith <smolsheep@opensuse.org>
- Add keyring and signature for package.
- Remove patches (Fixed upstream):
  * 0001-shm-create-mfd-noexec-seal.patch
  * 0002-fix-breakage-mfd-noexec-seal.patch
- Update to 1.10.2:
  * Crash when terminal=yes (in fuzzel.ini), and a .desktop file
    has Terminal=True but no Exec key.
  * --anchor=center not working on some compositors.
- Updates from 1.10.1:
  * Crash when executing the command line as is, i.e. when there is
    no matching entry.
  * Crash when parsing a .desktop file with lines beginning with
    whitespace.
- Updates from 1.10.0:
  Added:
  * Support for the cursor-shape-v1 Wayland protocol.
  * New option --anchor allows setting the window position anchor
    (i.e. where on the screen the window should generally be
    positioned), such as top, top-left, bottom-right, center, etc.
    Defaults to center.
  * --check-config command line option.
  * New key binding: execute-input (mapped to shift+return by
    default). This key binding executes the raw input as is,
    regardless of whether it matches anything in the list or not.
  * --select=STRING command line option. Selects the first entry
    that matches the given string.
  * include=<path> option to fuzzel.ini.
  * New option --list-executables-in-path add executables presents
    in the $PATH variable to the list.
  * New key binding: delete-line-backward which corresponds to C-u
    in bash. Also renames delete-line to delete-line-forward.
  * The ID of the selected .desktop file, and executed command line
    are now logged, at info level.
  * Support for wp_fractional_scale_v1 (i.e. true fractional
    scaling).
  Changed:
  * Minimum required version of wayland-protocols is now 1.32
  * Selection color is now painted over background color.
  * Exact matches (of the application title) are now sorted first.
  * Set default log level to warning.
  * Rename delete-line binding to delete-line-forward.
  * password-character can now be set to the empty string.
  Fixed:
  * Ignore whitespace in .desktop files’ key and name values.
  * Desktop entries with NoDisplay=true being ignored unless they
    also had Name and Exec set.
  * Crash when compositor sends a keyboard::modifiers event without
    first sending a keyboard::keymap event (with a valid keymap).
  * Quoted empty ("") arguments being ignored.
  * Log-level not respected by syslog.
* Sun Oct 22 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Rename 0001-mfd-noexec-seal.patch to 0002-fix-breakage-mfd-noexec-seal.patch
- Add 0001-shm-create-mfd-noexec-seal.patch
* Sun Oct 22 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Add 0001-mfd-noexec-seal.patch
* Fri Jul 14 2023 llyyr <llyyr.public@gmail.com>
- Update to 1.9.2:
  * Added a new option --filter-desktop
  * Added missing zsh+fish completions for --password
  * Output scaling is now applied to the border radius
  * Last line sometimes not being rendered
  * key-bindings.cursor-right-word not being recognized as a valid action
  * password-character being set in fuzzel.ini incorrectly enabling password mode
* Tue Apr 11 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Fix specfile
* Sat Apr  8 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Remove 0000-wayland-regression-dont-reference-app-when-null.patch
- Update to version 1.9.1
  - Fixed:
  * Regression: default font size was unintentionally changed from 12pt in 1.8.2, to 8pt in 1.9.0. The old default of 12pt has now been restored.
  * Regression: crash when pressing Enter and the match list is empty (e.g. when trying to execute a command line)
- Improvement of specfile
* Thu Mar 30 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Add 0000-wayland-regression-dont-reference-app-when-null.patch
* Tue Mar 28 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.9.0:
  - Added:
  * Add support for startup notifications via xdg activation.
  * Convert tabs to spaces when rendering.
  * --dmenu0 command line option. Like --dmenu, but input is NUL separated instead of newline separated.
  * Support for localized strings. If you want the old behavior, run fuzzel with LC_MESSAGES=C.
  * Export FUZZEL_DESKTOP_FILE_ID environment variable when setting the --launch-prefix in order to pass the Desktop File ID to the launch prefix.
  * New key bindings: [key-bindings].first and [key-bindings].last, bound to Control+Home and Control+End by default.
  * New key binding: [key-bindings].insert-selected, bound to Control+Tab by default. It replaces the current prompt with the selected item.
  - Changed:
  * Better verification of color values specified on the command line.
  * When determining initial font size, do FontConfig config substitution if the user-provided font pattern has no {pixel}size option.
  - Fixed:
  * Update nanosvg to f0a3e10. Fixes rendering of certain SVG icons.
  * Not being able to input numbers using the keypad.
  * Absolute path PNG icons not being loaded.
* Sat Nov  5 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.8.2:
  - Added:
  * Fish completions
  - Fixed:
  * Unsupported icon formats not being skipped when loading application icons.
  * Wrong size of PNG icons selected (#182)
* Fri Oct 28 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.8.1:
  - Fixed:
  * Regression: not able to input text with modifiers (e.g. Shift) pressed (#177).
* Tue Oct 25 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.8.0:
  - Added:
  * Support for file based configuration.
  * Customizable key bindings.
  * "Custom" key bindings (like Rofi’s `kb-custom-N` key
    bindings).
  * If `argv[0]` is _dmenu_, fuzzel now starts in dmenu mode.
  * `--password=[CHARACTER]` command line option. Intended to be used
    with “password input”; all typed text is rendered as _CHARACTER_,
    defaulting to `*` if _CHARACTER_ is omitted.
  * `Ctrl+y` binding to execute selected entry.
  * `Ctrl+j`/`Ctrl+k` binding to move to the next/previous item.
  * Escape sequences in `Exec` arguments are now supported.
  * Quoted environment variables in `Exec` arguments are now supported.
  * Multiple space-separated search words can now be entered at the prompt.
  * `-M,--selection-match-color`, that lets you configure the color of
    matched substrings of the currently selected item
  * New config option `image-size-ratio`, allowing you to control the
    size of the large image displayed when there are only a “few”
    matches.
  * Support for icons in dmenu mode, using Rofi’s extended dmenu
    protocol.
  * `--layer` command line option, allowing you to choose which layer to
    render the fuzzel window on (`top` or `overlay`).
  * `--no-exit-on-keyboard-focus-loss` command line option
    (`exit-on-keyboard-focus-loss` config option).
  - Changed:
  * `-i` is now **ignored**. This is to increase compatibility with
    other similar utilities. To set the icon theme, either use the long
    option (`--icon-theme=THEME`), or set it in the configuration file
    (default: `$XDG_CONFIG_HOME/fuzzel/fuzzel.ini`).
  * Minimum required meson version is now 0.58.
  * libpng warnings are now routed through fuzzel’s logging
    ([#101][101]).
  * Nanosvg is now the default SVG backend. librsvg is still supported,
    and can be used by setting the `-Dsvg-backend=librsvg` meson option.
  * It is no longer necessary to close stdin when using fuzzel in dmenu
    mode, as long as `--no-run-if-empty` is **not** being used.
  * Improved performance of initial rendering of icons.
  * `--terminal` now defaults to `$TERMINAL -e`.
  * Font shaping is now applied to the prompt
  * The large image displayed when there are only a “few” matches is now
    smaller by default.
  * Swapped meaning of the command line options `-p` and `-P`; `-p` is
    now the short option for `--prompt`.
  * Do not add icon-sized padding on the left size in dmenu mode.
  * Color config values are now allowed to be prefixed with `#`.
  - Fixed:
  * User `.desktop` entries with `NoDisplay=true` not overriding system
    entries.
  * Icon lookup is now better at following the XDG specification.
  * Backspace removes not only the previous character, but also
    everything **after** the cursor.
  * Crash on exit in dmenu mode when selection list is empty.
  * Keypad `enter` not executing the selected entry
- Fix build for meson having issue with c18 standard in spec by
  setting it to none. C18 standard is already supported in
  meson long before version 0.58.
* Fri Apr 22 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- remove librsvg-2.0 as build dependency:
  * we use nanosvg that is bundled with the package instead with flag '-Dsvg-backend=nanosvg'
* Mon Mar  7 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec file for fuzzel (1.7.0)
